Coverage for /Users/davegaeddert/Developer/dropseed/plain/plain-sessions/plain/sessions/migrations/0002_alter_session_options_alter_session_expire_date_and_more.py: 100%

1# Generated by Plain 5.0.dev20230814020017 on 2023-08-14 02:09

2

3 from plain import models

4 from plain.models import migrations

5

6

7 class Migration(migrations.Migration):

8 dependencies = [

9 ("plainsessions", "0001_initial"),

10 ]

11

12 operations = [

13 migrations.AlterModelOptions(

14 name="session",

15 options={},

16 ),

17 migrations.AlterField(

18 model_name="session",

19 name="expire_date",

20 field=models.DateTimeField(db_index=True),

21 ),

22 migrations.AlterField(

23 model_name="session",

24 name="session_data",

25 field=models.TextField(),

26 ),

27 migrations.AlterField(

28 model_name="session",

29 name="session_key",

30 field=models.CharField(max_length=40, primary_key=True),

31 ),

32 ]